@@ -25,31 +25,31 @@ namespace Gdk {
 
 	public class EventButton : Event {
 
-		[DllImport("gdksharpglue-2", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("gdksharpglue-2")]
 		static extern uint gtksharp_gdk_event_button_get_time (IntPtr evt);
 
-		[DllImport("gdksharpglue-2", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("gdksharpglue-2")]
 		static extern double gtksharp_gdk_event_button_get_x (IntPtr evt);
 
-		[DllImport("gdksharpglue-2", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("gdksharpglue-2")]
 		static extern double gtksharp_gdk_event_button_get_y (IntPtr evt);
 
-		[DllImport("gdksharpglue-2", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("gdksharpglue-2")]
 		static extern double gtksharp_gdk_event_button_get_x_root (IntPtr evt);
 
-		[DllImport("gdksharpglue-2", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("gdksharpglue-2")]
 		static extern double gtksharp_gdk_event_button_get_y_root (IntPtr evt);
 
-		[DllImport("gdksharpglue-2", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("gdksharpglue-2")]
 		static extern uint gtksharp_gdk_event_button_get_state (IntPtr evt);
 
-		[DllImport("gdksharpglue-2", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("gdksharpglue-2")]
 		static extern uint gtksharp_gdk_event_button_get_button (IntPtr evt);
 
-		[DllImport("gdksharpglue-2", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("gdksharpglue-2")]
 		static extern IntPtr gtksharp_gdk_event_button_get_device (IntPtr evt);
 
-		[DllImport("gdksharpglue-2", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("gdksharpglue-2")]
 		static extern IntPtr gtksharp_gdk_event_button_get_axes (IntPtr evt);
 
 		public EventButton (IntPtr raw) : base (raw) {} 
