@@ -34,7 +34,7 @@ namespace GLib {
 		internal bool elements_owned = false;
 		protected System.Type element_type = null;
 
-                abstract internal IntPtr NthData (uint index);
+		abstract internal IntPtr NthData (uint index);
 		abstract internal IntPtr GetData (IntPtr current);
 		abstract internal IntPtr Next (IntPtr current);
 		abstract internal int Length (IntPtr list);
@@ -76,6 +76,11 @@ namespace GLib {
 			this.Append (Marshaller.StringToPtrGStrdup (item));
 		}
 
+		public void Append (object item)
+		{
+			this.Append (AllocNativeElement (item));
+		}
+
 		public void Prepend (IntPtr raw)
 		{
 			list_ptr = Prepend (list_ptr, raw);
@@ -113,7 +118,7 @@ namespace GLib {
 			object[] orig = new object[Count];
 			int i = 0;
 			foreach (object o in this)
-				orig[i++] = o;
+				orig [i++] = o;
 			
 			orig.CopyTo (array, index); 
 		}
@@ -122,6 +127,30 @@ namespace GLib {
 			private FilenameString () {}
 		}
 
+		IntPtr AllocNativeElement (object element)
+		{
+			if (element_type == null) {
+				if (element is IWrapper)
+					return (element as IWrapper).Handle;
+				else
+					return (IntPtr) GCHandle.Alloc (element);
+			} else {
+				if (element_type == typeof (string))
+					return Marshaller.StringToPtrGStrdup (element as string);
+				else if (element_type == typeof (FilenameString))
+					return Marshaller.StringToFilenamePtr (element as string);
+				else if (element_type == typeof (IntPtr))
+					return (IntPtr) GCHandle.Alloc (element);
+				else if (typeof (IWrapper).IsAssignableFrom (element_type))
+					return (element as IWrapper).Handle;
+				else if (element_type == typeof (int))
+					return new IntPtr ((int) element);
+				else if (element_type.IsValueType)
+					return Marshaller.StructureToPtrAlloc (element);
+			}
+			return IntPtr.Zero;
+		}
+
 		internal object DataMarshal (IntPtr data) 
 		{
 			object ret = null;
